{*******************************************************}
{                                                       }
{       JNI Wrapper for Delphi Demo 3                   }
{       Demonstrates the use of the JNIWrapper          }
{       classes to dynamically create an instance       }
{       of an object. A callback method is              }
{       defined to react to the java System exit.       }
{                                                       }
{       Copyright (c) 1998 Jonathan Revusky             }
{                                                       }
{       Java and Delphi Freelance programming           }
{             jrevusky@bigfoot.com                      }
{                                                       }
{*******************************************************}

program jtest3;

// example that shows how to instantiate an object
// and invoke a method on it using the JNI Wrapper

{$APPTYPE CONSOLE}

    
    uses
        Windows, SysUtils, Classes,
        JavaRuntime, JNIWrapper;
    
    var
        JNITest : TJavaClass;
        params : TJavaParams;
        TestObject : TJavaObject;
        Runtime : TJavaRuntime;
    
    procedure OnExit(exitCode : Integer); stdcall;
        begin
            writeln('exited with value ' + IntToStr(exitCode));
            halt;
        end;
    
    begin
        try
        //  Runtime := TJavaRuntime.Create(SunJava12); //use this line if you want 1.2 specifically.
        //  Runtime := TJavaRuntime.Create(MSJava); //or this line if you want MS specifically
        
            Runtime := TJavaRuntime.GetDefault;
            Runtime.ExitProc := @OnExit; // must be set before the JVM is used or has no effect.
            
            JNITest := TJavaClass.Create('HelloWorld');
            params := TJavaParams.Create;
            params.addString('JNI Test');
            params.addInt(200);
            params.addInt(200);
            TestObject := JNITest.Instantiate(params);
            Runtime.Wait; // Wait until the JVM has exited all the threads.
            
            // cleanup now just to be compulsive.
            params.free;
            TestObject.free;
            JNITest.Free;
        except
            on EJvmException do 
                ShowException(ExceptObject, ExceptAddr);
        end;
end.

