{*******************************************************}
{                                                       }
{       JNI Wrapper for Delphi Demo 4. A more           }
{       involved demonstration of the JNIWrapper        }
{       classes. A Frame and label are instantiated.    }
{       and displayed.                                  }
{                                                       }
{       Copyright (c) 1998 Jonathan Revusky             }
{                                                       }
{       Java and Delphi Freelance programming           }
{             jrevusky@bigfoot.com                      }
{                                                       }
{*******************************************************}

program jtest4;

//rather involved example showing how to
//create java objects and script them from delphi
// (Hmm, now remind me why anyone would want to do this...)

{$APPTYPE CONSOLE}

    uses
        Windows, SysUtils, Classes,
        JavaRuntime, JNIWrapper;

    var
        params : TJavaParams;
        FrameClass, LabelClass, ComponentClass : TJavaClass;
        FrameObject, LabelObject : TJavaObject;
        setVisible, setSize, setLocation, add, setText : TJavaMethod;
        Runtime : TJavaRuntime;
        I: Integer;

    procedure OnExit(exitCode : Integer); stdcall;
        begin
            writeln('exited with value ' + IntToStr(exitCode));
        end;

    begin
        try
            Runtime := TJavaRuntime.GetDefault;
            Runtime.ExitProc := @OnExit; // must be called before the VM is used to have any effect.

            // Get references to the java classes we need.
            FrameClass := TJavaClass.Create('java.awt.Frame');
            LabelClass := TJavaClass.Create('java.awt.Label');
            ComponentClass := TJavaClass.Create('java.awt.Component');

            // Create the Frame.
            params := TJavaParams.Create;
            params.addString('JNI Demo 4');
            FrameObject := FrameClass.Instantiate(params);
            params.Free;

            // Create the Label.
            params := TJavaParams.Create;
            params.addString('Just give me 10 seconds....');
            params.addInt(1); //The constant Label.CENTER is 1.
            LabelObject := LabelClass.Instantiate(params);
            params.Free;

            // Add the Label to the Frame.
            params := TJavaParams.Create;
            params.addString('South');
            params.addObject(LabelObject, ComponentClass);
            add := TJavaMethod.Create(FrameClass, 'add', nonstatic, aObject, params, ComponentClass);
            add.Call(params, FrameObject);
            params.Free;

            // Call setSize() on the Frame.
            params := TJavaParams.Create;
            params.addInt(200);
            params.addInt(100);
            setSize := TJavaMethod.Create(FrameClass, 'setSize', nonstatic, void, params, nil);
            setSize.call(params, FrameObject);
            params.free;

            // Call setLocation() on the Frame.
            params := TJavaParams.Create;
            params.addInt(300);
            params.addInt(200);
            setLocation := TJavaMethod.Create(FrameClass, 'setLocation', nonstatic, void, params, nil);
            setLocation.call(params, FrameObject);
            params.free;

            // Call setVisible() on the Frame.
            params := TJavaParams.Create;
            params.addboolean(true);
            setVisible := TJavaMethod.Create(FrameClass, 'setVisible', nonstatic, void, params, nil);
            setVisible.call(params, FrameObject);
            params.free;

            // Call setText() on the Label
            params := TJavaParams.Create;
            params.addString('Will count down from 10');
            setText := TJavaMethod.Create(LabelClass, 'setText', nonstatic, void, params, nil);
            setText.call(params, LabelObject);

            for I:=9 downto 0 do
                begin
            // Pause for one second (approximately)
                    Sleep(1000);
                    params := TJavaParams.Create;
                    params.addString(IntToStr(I) + ' seconds left');
                    setText.call(params, LabelObject);
                    params.free;
                end;

            //Free the objects that were defined.
            add.Free;
            setSize.Free;
            setLocation.Free;
            setText.Free;
            setVisible.Free;
            FrameObject.Free;
            LabelObject.Free;
            FrameClass.Free;
            LabelClass.Free;
            ComponentClass.Free;

            // Convenience method. Calls System.exit()
            Runtime.CallExit(1234);

            // Exception handler
        except
            on EJvmException do
                ShowException(ExceptObject, ExceptAddr);
        end;
end.

